
const path = require('path')
const yaml = require('js-yaml')
const fs = require('fs');

/**
 *
 */
module.exports = function(customConfig) {
  const {webpackDir, nodeModulesDir} = customConfig

  const entryMap = {};
  const commonsDir = `${webpackDir}/commons`
  const entriesDir = `${webpackDir}/entries`

  if (fs.existsSync(entriesDir)) {
    for (const entry of getNamesFromDirectory(entriesDir)) {
      entryMap[`entries/${entry}`] = `./entries/${entry}`;
    }
  }
  if (fs.existsSync(commonsDir)) {
    for (const common of getNamesFromDirectory(commonsDir)) {
      entryMap[`commons/${common}`] = `./commons/${common}`;
    }
  }

  return {
    context: webpackDir,
    entry: entryMap,
    output: {
      path         : '/tmp/perch-app',
      publicPath   : '/',
      filename     : 'js/[name].js',
      chunkFilename: 'js/chunk/[id].js',
    },
    resolve: {
      modules: [
        webpackDir,
        nodeModulesDir,
      ],
      descriptionFiles: ['package.json'],
      mainFields: ['main', 'browser'],
      mainFiles: ['index'],
      extensions: [
        '.js',
      ],
      enforceExtension: false,
      enforceModuleExtension: false,
    },
    devServer: {
      contentBase: webpackDir,
      host: '0.0.0.0',
      disableHostCheck: true,
      stats: {
        assets: false,
        colors: true,
        children: false,
        chunks: false,
        modules: false,
      },
    },
  }
}

/**
 *
 */
function getNamesFromDirectory(filepath) {
  return fs
    .readdirSync(filepath)
    .filter(filename => filename[0] !== '#')
    .map(filename => {
      let entryName, ext
      if (fs.lstatSync(`${filepath}/${filename}`).isDirectory()) {
        entryName = filename
      } else {
        ext = path.extname(filename)
        entryName = filename.substr(0, filename.length - ext.length)
      }
      return entryName
    })
}